==> haskell-bower-json-1.0.0.1-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-ANPdoG8bHh72ORzoyawkEf
key: bower-json-1.0.0.1-ANPdoG8bHh72ORzoyawkEf
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
abi: 251d9b2ff4ce71bb5df39339b8e8c0a0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-ANPdoG8bHh72ORzoyawkEf
depends:
    aeson-1.1.2.0-4o7xkQ7uWQx1uZeT7K0c7O
    aeson-better-errors-0.9.1.0-KUO1VcpI3XAIOmUIWJBRK base-4.9.1.0
    bytestring-0.10.8.1 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    scientific-0.3.4.15-HctpzcRgjZy3SiZcFaAYzr
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-28iLOIJkebMKusvrEC7TGP
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-LWDYm1WeiXrIEMwma8obee
key: bower-json-1.0.0.1-LWDYm1WeiXrIEMwma8obee
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
abi: 6d980ca3edba928da350ec7055771713
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-LWDYm1WeiXrIEMwma8obee
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9
    aeson-better-errors-0.9.1.0-6Sia7NgsoY44TfKEiKAR8n base-4.9.1.0
    bytestring-0.10.8.1 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    scientific-0.3.5.0-7hRLtQzMvnkCQbsJuyPHcq
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
